/**
 * Database Management API
 * Use the Database Management API to monitor and manage resources such as
Oracle Databases, MySQL Databases, and External Database Systems.
For more information, see [Database Management](https://docs.oracle.com/iaas/database-management/home.htm).

 * OpenAPI spec version: 20201101
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * The details of a cloud listener.
 */
export interface CloudListener {
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the cloud listener.
     */
    "id": string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) in DBaas service.
     */
    "dbaasId"?: string;
    /**
     * The user-friendly name for the cloud listener. The name does not have to be unique.
     */
    "displayName": string;
    /**
     * The name of the cloud listener.
     */
    "componentName": string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
     */
    "compartmentId": string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the cloud DB system that the listener is a part of.
     */
    "cloudDbSystemId": string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the cloud connector.
     */
    "cloudConnectorId"?: string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the cloud DB node.
     */
    "cloudDbNodeId"?: string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the cloud DB home.
     */
    "cloudDbHomeId"?: string;
    /**
     * The listener alias.
     */
    "listenerAlias"?: string;
    /**
     * The type of listener.
     */
    "listenerType"?: CloudListener.ListenerType;
    /**
     * The additional details of the cloud listener defined in {@code {\"key\": \"value\"}} format.
     * Example: {@code {\"bar-key\": \"value\"}}
     *
     */
    "additionalDetails"?: {
        [key: string]: string;
    };
    /**
     * The current lifecycle state of the cloud listener.
     */
    "lifecycleState": CloudListener.LifecycleState;
    /**
     * Additional information about the current lifecycle state.
     */
    "lifecycleDetails"?: string;
    /**
     * The location of the listener configuration file listener.ora.
     */
    "listenerOraLocation"?: string;
    /**
     * The Oracle home location of the listener.
     */
    "oracleHome"?: string;
    /**
     * The name of the host on which the cloud listener is running.
     */
    "hostName"?: string;
    /**
     * The directory that stores tracing and logging incidents when Automatic Diagnostic Repository (ADR) is enabled.
     */
    "adrHomeDirectory"?: string;
    /**
     * The destination directory of the listener log file.
     */
    "logDirectory"?: string;
    /**
     * The destination directory of the listener trace file.
     */
    "traceDirectory"?: string;
    /**
     * The listener version.
     */
    "version"?: string;
    /**
     * The list of protocol addresses the listener is configured to listen on.
     */
    "endpoints"?: Array<model.CloudListenerEndpoint>;
    /**
     * The list of databases that are serviced by the listener.
     */
    "servicedDatabases"?: Array<model.CloudListenerServicedDatabase>;
    /**
     * The list of ASMs that are serviced by the listener.
     */
    "servicedAsms"?: Array<model.CloudServicedAsm>;
    /**
     * The date and time the cloud listener was created.
     */
    "timeCreated": Date;
    /**
     * The date and time the cloud listener was last updated.
     */
    "timeUpdated": Date;
    /**
     * Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
     * For more information, see [Resource Tags](https://docs.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
     * Example: {@code {\"Department\": \"Finance\"}}
     *
     */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * For more information, see [Resource Tags](https://docs.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
     * Example: {@code {\"Operations\": {\"CostCenter\": \"42\"}}}
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
      * System tags for this resource. Each key is predefined and scoped to a namespace.
  * For more information, see [Resource Tags](https://docs.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
  * System tags can be viewed by users, but can only be created by the system.
  * <p>
  Example: {@code {\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}}
  *
      */
    "systemTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace CloudListener {
    enum ListenerType {
        Asm = "ASM",
        Local = "LOCAL",
        Scan = "SCAN",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum LifecycleState {
        Creating = "CREATING",
        NotConnected = "NOT_CONNECTED",
        Active = "ACTIVE",
        Inactive = "INACTIVE",
        Updating = "UPDATING",
        Deleting = "DELETING",
        Deleted = "DELETED",
        Failed = "FAILED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: CloudListener): object;
    function getDeserializedJsonObj(obj: CloudListener): object;
}
