/**
 * Oracle Database MultiCloud Data plane Integration
 * 1. Oracle Azure Connector Resource: This is for installing Azure Arc Server in ExaCS VM Cluster.
  There are two way to install Azure Arc Server (Azure Identity) in ExaCS VMCluster.
    a. Using Bearer Access Token or
    b. By providing Authentication token

2. Oracle Azure Blob Container Resource: This is for to capture Azure Container details
   and same will be used in multiple ExaCS VMCluster to mount the Azure Container.

3. Oracle Azure Blob Mount Resource: This is for to mount Azure Container in ExaCS VMCluster
   using Oracle Azure Connector and Oracle Azure Blob Container Resource.

 * OpenAPI spec version: 20240501
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { MultiCloudResourceDiscoveryWaiter } from "./multicloudresourcediscovery-waiter";
import { OracleDBAzureBlobContainerWaiter } from "./oracledbazureblobcontainer-waiter";
import { OracleDBAzureBlobMountWaiter } from "./oracledbazureblobmount-waiter";
import { OracleDBAzureConnectorWaiter } from "./oracledbazureconnector-waiter";
import { OracleDbAzureKeyWaiter } from "./oracledbazurekey-waiter";
import { OracleDbAzureVaultWaiter } from "./oracledbazurevault-waiter";
import { OracleDbAzureVaultAssociationWaiter } from "./oracledbazurevaultassociation-waiter";
import { WorkRequestWaiter } from "./workrequest-waiter";
declare const Breaker: any;
export declare enum MultiCloudResourceDiscoveryApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class MultiCloudResourceDiscoveryClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": MultiCloudResourceDiscoveryWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    protected _authProvider: common.AuthenticationDetailsProvider | undefined;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new MultiCloudResourceDiscoveryWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): MultiCloudResourceDiscoveryWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): MultiCloudResourceDiscoveryWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the provider if possible which in turn shuts down any associated circuit breaker
     */
    closeProvider(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Moves the Oracle Azure Vault resource into a different compartment. When provided, 'If-Match' is checked against 'ETag' values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeMultiCloudResourceDiscoveryCompartmentRequest
     * @return ChangeMultiCloudResourceDiscoveryCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/ChangeMultiCloudResourceDiscoveryCompartment.ts.html |here} to see how to use ChangeMultiCloudResourceDiscoveryCompartment API.
     */
    changeMultiCloudResourceDiscoveryCompartment(changeMultiCloudResourceDiscoveryCompartmentRequest: requests.ChangeMultiCloudResourceDiscoveryCompartmentRequest): Promise<responses.ChangeMultiCloudResourceDiscoveryCompartmentResponse>;
    /**
     * Discover Azure Vaults and Keys based on the provided information.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateMultiCloudResourceDiscoveryRequest
     * @return CreateMultiCloudResourceDiscoveryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/CreateMultiCloudResourceDiscovery.ts.html |here} to see how to use CreateMultiCloudResourceDiscovery API.
     */
    createMultiCloudResourceDiscovery(createMultiCloudResourceDiscoveryRequest: requests.CreateMultiCloudResourceDiscoveryRequest): Promise<responses.CreateMultiCloudResourceDiscoveryResponse>;
    /**
     * Delete Multi Cloud Discovery resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteMultiCloudResourceDiscoveryRequest
     * @return DeleteMultiCloudResourceDiscoveryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/DeleteMultiCloudResourceDiscovery.ts.html |here} to see how to use DeleteMultiCloudResourceDiscovery API.
     */
    deleteMultiCloudResourceDiscovery(deleteMultiCloudResourceDiscoveryRequest: requests.DeleteMultiCloudResourceDiscoveryRequest): Promise<responses.DeleteMultiCloudResourceDiscoveryResponse>;
    /**
     * Get Multi Cloud Discovered Resource Details form a particular resource ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetMultiCloudResourceDiscoveryRequest
     * @return GetMultiCloudResourceDiscoveryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/GetMultiCloudResourceDiscovery.ts.html |here} to see how to use GetMultiCloudResourceDiscovery API.
     */
    getMultiCloudResourceDiscovery(getMultiCloudResourceDiscoveryRequest: requests.GetMultiCloudResourceDiscoveryRequest): Promise<responses.GetMultiCloudResourceDiscoveryResponse>;
    /**
     * Lists the all Multi Cloud Resource Discovery based on filters.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListMultiCloudResourceDiscoveriesRequest
     * @return ListMultiCloudResourceDiscoveriesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/ListMultiCloudResourceDiscoveries.ts.html |here} to see how to use ListMultiCloudResourceDiscoveries API.
     */
    listMultiCloudResourceDiscoveries(listMultiCloudResourceDiscoveriesRequest: requests.ListMultiCloudResourceDiscoveriesRequest): Promise<responses.ListMultiCloudResourceDiscoveriesResponse>;
    /**
     * Modifies the existing Azure Discovered Resource for a given ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateMultiCloudResourceDiscoveryRequest
     * @return UpdateMultiCloudResourceDiscoveryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/UpdateMultiCloudResourceDiscovery.ts.html |here} to see how to use UpdateMultiCloudResourceDiscovery API.
     */
    updateMultiCloudResourceDiscovery(updateMultiCloudResourceDiscoveryRequest: requests.UpdateMultiCloudResourceDiscoveryRequest): Promise<responses.UpdateMultiCloudResourceDiscoveryResponse>;
}
export declare enum OracleDBAzureBlobContainerApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class OracleDBAzureBlobContainerClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": OracleDBAzureBlobContainerWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    protected _authProvider: common.AuthenticationDetailsProvider | undefined;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new OracleDBAzureBlobContainerWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): OracleDBAzureBlobContainerWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): OracleDBAzureBlobContainerWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the provider if possible which in turn shuts down any associated circuit breaker
     */
    closeProvider(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Moves the Oracle DB Azure Blob Container resource into a different compartment. When provided, 'If-Match' is checked against 'ETag' values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeOracleDbAzureBlobContainerCompartmentRequest
     * @return ChangeOracleDbAzureBlobContainerCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/ChangeOracleDbAzureBlobContainerCompartment.ts.html |here} to see how to use ChangeOracleDbAzureBlobContainerCompartment API.
     */
    changeOracleDbAzureBlobContainerCompartment(changeOracleDbAzureBlobContainerCompartmentRequest: requests.ChangeOracleDbAzureBlobContainerCompartmentRequest): Promise<responses.ChangeOracleDbAzureBlobContainerCompartmentResponse>;
    /**
     * Capture Azure Container details for mounting Azure Container on multiple OCI Database Resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateOracleDbAzureBlobContainerRequest
     * @return CreateOracleDbAzureBlobContainerResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/CreateOracleDbAzureBlobContainer.ts.html |here} to see how to use CreateOracleDbAzureBlobContainer API.
     */
    createOracleDbAzureBlobContainer(createOracleDbAzureBlobContainerRequest: requests.CreateOracleDbAzureBlobContainerRequest): Promise<responses.CreateOracleDbAzureBlobContainerResponse>;
    /**
     * Delete Oracle DB Azure Blob Container details.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteOracleDbAzureBlobContainerRequest
     * @return DeleteOracleDbAzureBlobContainerResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/DeleteOracleDbAzureBlobContainer.ts.html |here} to see how to use DeleteOracleDbAzureBlobContainer API.
     */
    deleteOracleDbAzureBlobContainer(deleteOracleDbAzureBlobContainerRequest: requests.DeleteOracleDbAzureBlobContainerRequest): Promise<responses.DeleteOracleDbAzureBlobContainerResponse>;
    /**
     * Get Oracle DB Azure Blob Container Details form a particular Container Resource ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetOracleDbAzureBlobContainerRequest
     * @return GetOracleDbAzureBlobContainerResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/GetOracleDbAzureBlobContainer.ts.html |here} to see how to use GetOracleDbAzureBlobContainer API.
     */
    getOracleDbAzureBlobContainer(getOracleDbAzureBlobContainerRequest: requests.GetOracleDbAzureBlobContainerRequest): Promise<responses.GetOracleDbAzureBlobContainerResponse>;
    /**
     * Lists the all Oracle DB Azure Blob Container based on filter.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOracleDbAzureBlobContainersRequest
     * @return ListOracleDbAzureBlobContainersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/ListOracleDbAzureBlobContainers.ts.html |here} to see how to use ListOracleDbAzureBlobContainers API.
     */
    listOracleDbAzureBlobContainers(listOracleDbAzureBlobContainersRequest: requests.ListOracleDbAzureBlobContainersRequest): Promise<responses.ListOracleDbAzureBlobContainersResponse>;
    /**
     * Modifies the existing Oracle DB Azure Blob Container for a given ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateOracleDbAzureBlobContainerRequest
     * @return UpdateOracleDbAzureBlobContainerResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/UpdateOracleDbAzureBlobContainer.ts.html |here} to see how to use UpdateOracleDbAzureBlobContainer API.
     */
    updateOracleDbAzureBlobContainer(updateOracleDbAzureBlobContainerRequest: requests.UpdateOracleDbAzureBlobContainerRequest): Promise<responses.UpdateOracleDbAzureBlobContainerResponse>;
}
export declare enum OracleDBAzureBlobMountApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class OracleDBAzureBlobMountClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": OracleDBAzureBlobMountWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    protected _authProvider: common.AuthenticationDetailsProvider | undefined;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new OracleDBAzureBlobMountWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): OracleDBAzureBlobMountWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): OracleDBAzureBlobMountWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the provider if possible which in turn shuts down any associated circuit breaker
     */
    closeProvider(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Moves the Oracle DbAzure Blob Mount resource into a different compartment. When provided, 'If-Match' is checked against 'ETag' values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeOracleDbAzureBlobMountCompartmentRequest
     * @return ChangeOracleDbAzureBlobMountCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/ChangeOracleDbAzureBlobMountCompartment.ts.html |here} to see how to use ChangeOracleDbAzureBlobMountCompartment API.
     */
    changeOracleDbAzureBlobMountCompartment(changeOracleDbAzureBlobMountCompartmentRequest: requests.ChangeOracleDbAzureBlobMountCompartmentRequest): Promise<responses.ChangeOracleDbAzureBlobMountCompartmentResponse>;
    /**
     * Creates Oracle DB Azure Blob Mount resource and mounts Azure Container in OCI Database Resource,
     * based on provided Azure Container details and Database Resource ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateOracleDbAzureBlobMountRequest
     * @return CreateOracleDbAzureBlobMountResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/CreateOracleDbAzureBlobMount.ts.html |here} to see how to use CreateOracleDbAzureBlobMount API.
     */
    createOracleDbAzureBlobMount(createOracleDbAzureBlobMountRequest: requests.CreateOracleDbAzureBlobMountRequest): Promise<responses.CreateOracleDbAzureBlobMountResponse>;
    /**
     * Unmount Azure Container Resource from ExaCS VM Cluster and Delete resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteOracleDbAzureBlobMountRequest
     * @return DeleteOracleDbAzureBlobMountResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/DeleteOracleDbAzureBlobMount.ts.html |here} to see how to use DeleteOracleDbAzureBlobMount API.
     */
    deleteOracleDbAzureBlobMount(deleteOracleDbAzureBlobMountRequest: requests.DeleteOracleDbAzureBlobMountRequest): Promise<responses.DeleteOracleDbAzureBlobMountResponse>;
    /**
     * Get Oracle DB Azure Blob Mount Details form a particular Container Resource ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetOracleDbAzureBlobMountRequest
     * @return GetOracleDbAzureBlobMountResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/GetOracleDbAzureBlobMount.ts.html |here} to see how to use GetOracleDbAzureBlobMount API.
     */
    getOracleDbAzureBlobMount(getOracleDbAzureBlobMountRequest: requests.GetOracleDbAzureBlobMountRequest): Promise<responses.GetOracleDbAzureBlobMountResponse>;
    /**
     * Lists the all Oracle DB Azure Blob Mounts based on filters.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOracleDbAzureBlobMountsRequest
     * @return ListOracleDbAzureBlobMountsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/ListOracleDbAzureBlobMounts.ts.html |here} to see how to use ListOracleDbAzureBlobMounts API.
     */
    listOracleDbAzureBlobMounts(listOracleDbAzureBlobMountsRequest: requests.ListOracleDbAzureBlobMountsRequest): Promise<responses.ListOracleDbAzureBlobMountsResponse>;
    /**
     * Modifies the existing Oracle DB Azure Blob Mount resource for a given ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateOracleDbAzureBlobMountRequest
     * @return UpdateOracleDbAzureBlobMountResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/UpdateOracleDbAzureBlobMount.ts.html |here} to see how to use UpdateOracleDbAzureBlobMount API.
     */
    updateOracleDbAzureBlobMount(updateOracleDbAzureBlobMountRequest: requests.UpdateOracleDbAzureBlobMountRequest): Promise<responses.UpdateOracleDbAzureBlobMountResponse>;
}
export declare enum OracleDBAzureConnectorApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class OracleDBAzureConnectorClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": OracleDBAzureConnectorWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    protected _authProvider: common.AuthenticationDetailsProvider | undefined;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new OracleDBAzureConnectorWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): OracleDBAzureConnectorWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): OracleDBAzureConnectorWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the provider if possible which in turn shuts down any associated circuit breaker
     */
    closeProvider(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Moves the Oracle DB Azure Connector Resource into a different compartment. When provided, 'If-Match' is checked against 'ETag' values of the resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeOracleDbAzureConnectorCompartmentRequest
     * @return ChangeOracleDbAzureConnectorCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/ChangeOracleDbAzureConnectorCompartment.ts.html |here} to see how to use ChangeOracleDbAzureConnectorCompartment API.
     */
    changeOracleDbAzureConnectorCompartment(changeOracleDbAzureConnectorCompartmentRequest: requests.ChangeOracleDbAzureConnectorCompartmentRequest): Promise<responses.ChangeOracleDbAzureConnectorCompartmentResponse>;
    /**
     * Creates Oracle DB Azure Connector Resource and configured Azure Identity in OCI Database Resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateOracleDbAzureConnectorRequest
     * @return CreateOracleDbAzureConnectorResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/CreateOracleDbAzureConnector.ts.html |here} to see how to use CreateOracleDbAzureConnector API.
     */
    createOracleDbAzureConnector(createOracleDbAzureConnectorRequest: requests.CreateOracleDbAzureConnectorRequest): Promise<responses.CreateOracleDbAzureConnectorResponse>;
    /**
     * Delete Oracle DB Azure Connector Resource and delete Azure Arc Identity too from Database Resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteOracleDbAzureConnectorRequest
     * @return DeleteOracleDbAzureConnectorResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/DeleteOracleDbAzureConnector.ts.html |here} to see how to use DeleteOracleDbAzureConnector API.
     */
    deleteOracleDbAzureConnector(deleteOracleDbAzureConnectorRequest: requests.DeleteOracleDbAzureConnectorRequest): Promise<responses.DeleteOracleDbAzureConnectorResponse>;
    /**
     * Get Oracle DB Azure Connector Resource form a particular Resource ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetOracleDbAzureConnectorRequest
     * @return GetOracleDbAzureConnectorResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/GetOracleDbAzureConnector.ts.html |here} to see how to use GetOracleDbAzureConnector API.
     */
    getOracleDbAzureConnector(getOracleDbAzureConnectorRequest: requests.GetOracleDbAzureConnectorRequest): Promise<responses.GetOracleDbAzureConnectorResponse>;
    /**
     * Lists the all Oracle DB Azure Connector Resource based on filters.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOracleDbAzureConnectorsRequest
     * @return ListOracleDbAzureConnectorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/ListOracleDbAzureConnectors.ts.html |here} to see how to use ListOracleDbAzureConnectors API.
     */
    listOracleDbAzureConnectors(listOracleDbAzureConnectorsRequest: requests.ListOracleDbAzureConnectorsRequest): Promise<responses.ListOracleDbAzureConnectorsResponse>;
    /**
     * Patch Azure Arc Agent on VM Cluster with new version.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param PatchOracleDbAzureConnectorRequest
     * @return PatchOracleDbAzureConnectorResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/PatchOracleDbAzureConnector.ts.html |here} to see how to use PatchOracleDbAzureConnector API.
     */
    patchOracleDbAzureConnector(patchOracleDbAzureConnectorRequest: requests.PatchOracleDbAzureConnectorRequest): Promise<responses.PatchOracleDbAzureConnectorResponse>;
    /**
     * Modifies the existing Oracle DB Azure Connector Resource for a given ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateOracleDbAzureConnectorRequest
     * @return UpdateOracleDbAzureConnectorResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/UpdateOracleDbAzureConnector.ts.html |here} to see how to use UpdateOracleDbAzureConnector API.
     */
    updateOracleDbAzureConnector(updateOracleDbAzureConnectorRequest: requests.UpdateOracleDbAzureConnectorRequest): Promise<responses.UpdateOracleDbAzureConnectorResponse>;
}
export declare enum OracleDbAzureKeyApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class OracleDbAzureKeyClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": OracleDbAzureKeyWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    protected _authProvider: common.AuthenticationDetailsProvider | undefined;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new OracleDbAzureKeyWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): OracleDbAzureKeyWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): OracleDbAzureKeyWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the provider if possible which in turn shuts down any associated circuit breaker
     */
    closeProvider(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Get Oracle DB Azure Key Details form a particular Container Resource ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetOracleDbAzureKeyRequest
     * @return GetOracleDbAzureKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/GetOracleDbAzureKey.ts.html |here} to see how to use GetOracleDbAzureKey API.
     */
    getOracleDbAzureKey(getOracleDbAzureKeyRequest: requests.GetOracleDbAzureKeyRequest): Promise<responses.GetOracleDbAzureKeyResponse>;
    /**
     * Lists the all Oracle DB Azure Keys based on filters.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOracleDbAzureKeysRequest
     * @return ListOracleDbAzureKeysResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/ListOracleDbAzureKeys.ts.html |here} to see how to use ListOracleDbAzureKeys API.
     */
    listOracleDbAzureKeys(listOracleDbAzureKeysRequest: requests.ListOracleDbAzureKeysRequest): Promise<responses.ListOracleDbAzureKeysResponse>;
}
export declare enum OracleDbAzureVaultApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class OracleDbAzureVaultClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": OracleDbAzureVaultWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    protected _authProvider: common.AuthenticationDetailsProvider | undefined;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new OracleDbAzureVaultWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): OracleDbAzureVaultWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): OracleDbAzureVaultWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the provider if possible which in turn shuts down any associated circuit breaker
     */
    closeProvider(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Moves the DB Azure Vault resource into a different compartment. When provided, 'If-Match' is checked against 'ETag' values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeOracleDbAzureVaultCompartmentRequest
     * @return ChangeOracleDbAzureVaultCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/ChangeOracleDbAzureVaultCompartment.ts.html |here} to see how to use ChangeOracleDbAzureVaultCompartment API.
     */
    changeOracleDbAzureVaultCompartment(changeOracleDbAzureVaultCompartmentRequest: requests.ChangeOracleDbAzureVaultCompartmentRequest): Promise<responses.ChangeOracleDbAzureVaultCompartmentResponse>;
    /**
     * Create DB Azure Vaults based on the provided information, this will fetch Keys related to Azure Vaults.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateOracleDbAzureVaultRequest
     * @return CreateOracleDbAzureVaultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/CreateOracleDbAzureVault.ts.html |here} to see how to use CreateOracleDbAzureVault API.
     */
    createOracleDbAzureVault(createOracleDbAzureVaultRequest: requests.CreateOracleDbAzureVaultRequest): Promise<responses.CreateOracleDbAzureVaultResponse>;
    /**
     * Delete  DB Azure Vault details.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteOracleDbAzureVaultRequest
     * @return DeleteOracleDbAzureVaultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/DeleteOracleDbAzureVault.ts.html |here} to see how to use DeleteOracleDbAzureVault API.
     */
    deleteOracleDbAzureVault(deleteOracleDbAzureVaultRequest: requests.DeleteOracleDbAzureVaultRequest): Promise<responses.DeleteOracleDbAzureVaultResponse>;
    /**
     * Get Oracle DB Azure Vault Details form a particular Container Resource ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetOracleDbAzureVaultRequest
     * @return GetOracleDbAzureVaultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/GetOracleDbAzureVault.ts.html |here} to see how to use GetOracleDbAzureVault API.
     */
    getOracleDbAzureVault(getOracleDbAzureVaultRequest: requests.GetOracleDbAzureVaultRequest): Promise<responses.GetOracleDbAzureVaultResponse>;
    /**
     * Lists the all DB Azure Vaults based on filters.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOracleDbAzureVaultsRequest
     * @return ListOracleDbAzureVaultsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/ListOracleDbAzureVaults.ts.html |here} to see how to use ListOracleDbAzureVaults API.
     */
    listOracleDbAzureVaults(listOracleDbAzureVaultsRequest: requests.ListOracleDbAzureVaultsRequest): Promise<responses.ListOracleDbAzureVaultsResponse>;
    /**
     * Refresh Oracle DB Azure Vault details from backend.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RefreshOracleDbAzureVaultRequest
     * @return RefreshOracleDbAzureVaultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/RefreshOracleDbAzureVault.ts.html |here} to see how to use RefreshOracleDbAzureVault API.
     */
    refreshOracleDbAzureVault(refreshOracleDbAzureVaultRequest: requests.RefreshOracleDbAzureVaultRequest): Promise<responses.RefreshOracleDbAzureVaultResponse>;
    /**
     * Modifies the existing Oracle DB Azure Vault Details for a given ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateOracleDbAzureVaultRequest
     * @return UpdateOracleDbAzureVaultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/UpdateOracleDbAzureVault.ts.html |here} to see how to use UpdateOracleDbAzureVault API.
     */
    updateOracleDbAzureVault(updateOracleDbAzureVaultRequest: requests.UpdateOracleDbAzureVaultRequest): Promise<responses.UpdateOracleDbAzureVaultResponse>;
}
export declare enum OracleDbAzureVaultAssociationApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class OracleDbAzureVaultAssociationClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": OracleDbAzureVaultAssociationWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    protected _authProvider: common.AuthenticationDetailsProvider | undefined;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new OracleDbAzureVaultAssociationWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): OracleDbAzureVaultAssociationWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): OracleDbAzureVaultAssociationWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the provider if possible which in turn shuts down any associated circuit breaker
     */
    closeProvider(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Delete Oracle DB Azure Vault Association details.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CascadingDeleteOracleDbAzureVaultAssociationRequest
     * @return CascadingDeleteOracleDbAzureVaultAssociationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/CascadingDeleteOracleDbAzureVaultAssociation.ts.html |here} to see how to use CascadingDeleteOracleDbAzureVaultAssociation API.
     */
    cascadingDeleteOracleDbAzureVaultAssociation(cascadingDeleteOracleDbAzureVaultAssociationRequest: requests.CascadingDeleteOracleDbAzureVaultAssociationRequest): Promise<responses.CascadingDeleteOracleDbAzureVaultAssociationResponse>;
    /**
     * Moves the Oracle DB Azure Vault Association resource into a different compartment. When provided, 'If-Match' is checked against 'ETag' values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeOracleDbAzureVaultAssociationCompartmentRequest
     * @return ChangeOracleDbAzureVaultAssociationCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/ChangeOracleDbAzureVaultAssociationCompartment.ts.html |here} to see how to use ChangeOracleDbAzureVaultAssociationCompartment API.
     */
    changeOracleDbAzureVaultAssociationCompartment(changeOracleDbAzureVaultAssociationCompartmentRequest: requests.ChangeOracleDbAzureVaultAssociationCompartmentRequest): Promise<responses.ChangeOracleDbAzureVaultAssociationCompartmentResponse>;
    /**
     * Create Oracle DB Azure Vault Association based on the provided information.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateOracleDbAzureVaultAssociationRequest
     * @return CreateOracleDbAzureVaultAssociationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/CreateOracleDbAzureVaultAssociation.ts.html |here} to see how to use CreateOracleDbAzureVaultAssociation API.
     */
    createOracleDbAzureVaultAssociation(createOracleDbAzureVaultAssociationRequest: requests.CreateOracleDbAzureVaultAssociationRequest): Promise<responses.CreateOracleDbAzureVaultAssociationResponse>;
    /**
     * Delete Oracle DB Azure Vault Association details.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteOracleDbAzureVaultAssociationRequest
     * @return DeleteOracleDbAzureVaultAssociationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/DeleteOracleDbAzureVaultAssociation.ts.html |here} to see how to use DeleteOracleDbAzureVaultAssociation API.
     */
    deleteOracleDbAzureVaultAssociation(deleteOracleDbAzureVaultAssociationRequest: requests.DeleteOracleDbAzureVaultAssociationRequest): Promise<responses.DeleteOracleDbAzureVaultAssociationResponse>;
    /**
     * Get Oracle DB Azure Vault Details Association form a particular Container Resource ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetOracleDbAzureVaultAssociationRequest
     * @return GetOracleDbAzureVaultAssociationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/GetOracleDbAzureVaultAssociation.ts.html |here} to see how to use GetOracleDbAzureVaultAssociation API.
     */
    getOracleDbAzureVaultAssociation(getOracleDbAzureVaultAssociationRequest: requests.GetOracleDbAzureVaultAssociationRequest): Promise<responses.GetOracleDbAzureVaultAssociationResponse>;
    /**
     * Lists the all Oracle DB Azure Associations based on filters.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOracleDbAzureVaultAssociationsRequest
     * @return ListOracleDbAzureVaultAssociationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/ListOracleDbAzureVaultAssociations.ts.html |here} to see how to use ListOracleDbAzureVaultAssociations API.
     */
    listOracleDbAzureVaultAssociations(listOracleDbAzureVaultAssociationsRequest: requests.ListOracleDbAzureVaultAssociationsRequest): Promise<responses.ListOracleDbAzureVaultAssociationsResponse>;
    /**
     * Modifies the existing Oracle DB Azure Vault Association Details for a given ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateOracleDbAzureVaultAssociationRequest
     * @return UpdateOracleDbAzureVaultAssociationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/UpdateOracleDbAzureVaultAssociation.ts.html |here} to see how to use UpdateOracleDbAzureVaultAssociation API.
     */
    updateOracleDbAzureVaultAssociation(updateOracleDbAzureVaultAssociationRequest: requests.UpdateOracleDbAzureVaultAssociationRequest): Promise<responses.UpdateOracleDbAzureVaultAssociationResponse>;
}
export declare enum WorkRequestApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class WorkRequestClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": WorkRequestWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    protected _authProvider: common.AuthenticationDetailsProvider | undefined;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new WorkRequestWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): WorkRequestWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): WorkRequestWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the provider if possible which in turn shuts down any associated circuit breaker
     */
    closeProvider(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Cancels a work request.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CancelWorkRequestRequest
     * @return CancelWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/CancelWorkRequest.ts.html |here} to see how to use CancelWorkRequest API.
     */
    cancelWorkRequest(cancelWorkRequestRequest: requests.CancelWorkRequestRequest): Promise<responses.CancelWorkRequestResponse>;
    /**
     * Gets details of the work request with the given ID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Returns a (paginated) list of errors for the work request with the given ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Returns a (paginated) list of logs for the work request with the given ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists the work requests in a compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/dbmulticloud/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
}
export {};
