/**
 * Oracle Database MultiCloud Data plane Integration
 * 1. Oracle Azure Connector Resource: This is for installing Azure Arc Server in ExaCS VM Cluster.
  There are two way to install Azure Arc Server (Azure Identity) in ExaCS VMCluster.
    a. Using Bearer Access Token or
    b. By providing Authentication token

2. Oracle Azure Blob Container Resource: This is for to capture Azure Container details
   and same will be used in multiple ExaCS VMCluster to mount the Azure Container.

3. Oracle Azure Blob Mount Resource: This is for to mount Azure Container in ExaCS VMCluster
   using Oracle Azure Connector and Oracle Azure Blob Container Resource.

 * OpenAPI spec version: 20240501
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Oracle DB Azure Connector Details, this resource is for to create Azure Identity on Database Resource.
 *
 */
export interface OracleDbAzureConnector {
    /**
     * The ID of the Oracle DB Azure Connector resource.
     */
    "id": string;
    /**
     * Oracle DB Azure Connector resource name.
     */
    "displayName"?: string;
    /**
     * The ID of the compartment that contains Oracle DB Azure Connector resource.
     */
    "compartmentId": string;
    /**
     * List of All VMs where Arc Agent is Install under VMCluster.
     */
    "arcAgentNodes"?: Array<model.ArcAgentNodes>;
    /**
     * The ID of the DB Cluster Resource where this Azure Arc Agent identity to configure.
     */
    "dbClusterResourceId": string;
    /**
     * Azure Tenant ID.
     */
    "azureTenantId": string;
    /**
     * Azure Subscription ID.
     */
    "azureSubscriptionId": string;
    /**
     * Azure Resource Group Name.
     */
    "azureResourceGroup": string;
    /**
     * Azure bearer access token. If bearer access token is provided then Service Principal detail is not required.
     */
    "accessToken"?: string;
    /**
     * Private endpoint IP.
     */
    "privateEndpointIpAddress"?: string;
    /**
     * Private endpoint DNS Alias.
     */
    "privateEndpointDnsAlias"?: string;
    /**
     * Azure Identity Mechanism.
     */
    "azureIdentityMechanism"?: OracleDbAzureConnector.AzureIdentityMechanism;
    /**
     * The current lifecycle state of the Azure Arc Agent Resource.
     */
    "lifecycleState"?: OracleDbAzureConnector.LifecycleState;
    /**
     * Description of the current lifecycle state in more detail.
     */
    "lifecycleStateDetails"?: string;
    /**
     * Time when the Oracle DB Azure Connector Resource was created expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339) timestamp format, e.g. '2020-05-22T21:10:29.600Z'
     *
     */
    "timeCreated"?: Date;
    /**
     * Time when the Oracle DB Azure Connector Resource was last modified expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339) timestamp format, e.g. '2020-05-22T21:10:29.600Z'
     *
     */
    "timeUpdated"?: Date;
    /**
     * Description of the latest modification of the Oracle DB Azure Connector Resource.
     */
    "lastModification"?: string;
    /**
      * Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
  * For more information, see [Resource Tags](https://docs.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: {@code {\"Department\": \"Finance\"}}
  *
      */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
      * Defined tags for this resource. Each key is predefined and scoped to a namespace.
  * For more information, see [Resource Tags](https://docs.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: {@code {\"Operations\": {\"CostCenter\": \"42\"}}}
  *
      */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
      * System tags for this resource. Each key is predefined and scoped to a namespace.
  * <p>
  Example: {@code {\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}}
  *
      */
    "systemTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace OracleDbAzureConnector {
    enum AzureIdentityMechanism {
        ArcAgent = "ARC_AGENT",
        ServicePrincipal = "SERVICE_PRINCIPAL",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum LifecycleState {
        Creating = "CREATING",
        Active = "ACTIVE",
        Updating = "UPDATING",
        Deleting = "DELETING",
        Deleted = "DELETED",
        Failed = "FAILED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: OracleDbAzureConnector): object;
    function getDeserializedJsonObj(obj: OracleDbAzureConnector): object;
}
